package Evo::Immune::MetaFunction;

use parent 'Evo:::GA::MetaFunction';

sub new {
	my ($class, $func) = @_;

	my $self = $class->SUPER::new($func);
}

### (partial) fitness function, sum of differ between antigens and antibodies
sub fitness_M0 ($antibody_genome, @args) {
	my $sum = 0;
	my $antigen_genome = @args[0];

	my $genome = $antibody_genome->genome_complement($antigen_genome);

	### FIXME use count perlism
	for (my $i = 0; $i < scalar $genome->{genes}; $i++) {
		if ($genome->{genes}[$i]) {
			$sum ++;
		}	
	}	
	
	return $sum;
}

1;
